"""YAML extension for jsonpickle

The YAML extension module connects jsonpickle to the PyYAML `yaml` module.
"""

from ..backend import json as jsonpickle_backend


def register(backend=None):
    """Register the yaml module with jsonpickle's JSONBackend"""
    if backend is None:
        backend = jsonpickle_backend
    return backend.load_backend(
        'yaml', dumps='dump', loads='safe_load', loads_exc='YAMLError'
    )



try:
    from importlib import metadata
except (ImportError, OSError):
    metadata = None


def _get_version():
    default_version = '0.0.0-alpha'
    try:
        version = metadata.version('jsonpickle')
    except (AttributeError, ImportError, OSError):
        version = default_version
    return version


__version__ = _get_version()
